==> haskell-lambdabot-trusted-5.3.1.2-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-7NC1G0k0yod6rmh3OJxeQL
key:                  lambdabot-trusted-5.3.1.2-7NC1G0k0yod6rmh3OJxeQL
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  093a3dc48b435b50d38897fecf6cb6c0
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-7NC1G0k0yod6rmh3OJxeQL
depends:
    QuickCheck-2.15.0.1-2V16aMn7v18E3ENFZVoJpj
    QuickCheck-safe-0.1.0.6-GaHghWcWUmH5iRX5qfxhmf base-4.17.2.1
    oeis-0.3.10.1-9sfEpWKd6ZLlrnnRSWxQx

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lambdabot-trusted-5.3.1.2-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-9wszzc5KkRPEgVRbaBb89M
key:                  lambdabot-trusted-5.3.1.2-9wszzc5KkRPEgVRbaBb89M
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  701a033619d2af98cf91e8633f7e9c6e
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-9wszzc5KkRPEgVRbaBb89M
depends:
    QuickCheck-2.15.0.1-I0djFeIgNIwKhHwbhHCf4p
    QuickCheck-safe-0.1.0.6-LhPXIv2pH0C4MI3EcZg2R9 base-4.17.2.1
    oeis-0.3.10.1-LP7JDkw5QSbIsnTcVRFuzu

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
